@@ -2,8 +2,10 @@ package cli
 
 import (
 	"fmt"
+	"strings"
 
 	"github.com/jandedobbeleer/oh-my-posh/src/font"
+	"github.com/jandedobbeleer/oh-my-posh/src/log"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 	"github.com/jandedobbeleer/oh-my-posh/src/terminal"
 
@@ -11,7 +13,8 @@ import (
 )
 
 var (
-	// fontCmd can work with fonts
+	zipFolder string
+
 	fontCmd = &cobra.Command{
 		Use:   "font [install|configure]",
 		Short: "Manage fonts",
@@ -46,7 +49,14 @@ This command is used to install fonts and configure the font in your terminal.
 
 				terminal.Init(env.Shell())
 
-				font.Run(fontName, env)
+				if !strings.HasPrefix(zipFolder, "/") {
+					zipFolder += "/"
+				}
+
+				if err := font.Run(fontName, env.Cache(), env.Root(), zipFolder); err != nil {
+					log.Error(err)
+					exitcode = 70
+				}
 
 				return
 			case "configure":
@@ -59,5 +69,6 @@ This command is used to install fonts and configure the font in your terminal.
 )
 
 func init() {
+	fontCmd.Flags().StringVar(&zipFolder, "zip-folder", "", "the folder inside the zip file to install fonts from")
 	RootCmd.AddCommand(fontCmd)
 }
