@@ -157,7 +157,7 @@ func (m *main) Init() tea.Cmd {
 
 		var fontAsset *Asset
 		for _, font := range fonts {
-			if m.URL != font.Name {
+			if !strings.EqualFold(m.URL, font.Name) {
 				continue
 			}
 
@@ -350,7 +350,11 @@ func (m *main) View() string {
 	return ""
 }
 
-func Run(font string, ch cache_.Cache, root bool, zipFolder string) {
+func SetCache(c cache_.Cache) {
+	cache = c
+}
+
+func Run(font string, ch cache_.Cache, root bool, zipFolder string) error {
 	main := &main{
 		system: root,
 		Asset: Asset{
@@ -360,11 +364,9 @@ func Run(font string, ch cache_.Cache, root bool, zipFolder string) {
 		},
 	}
 
-	cache = ch
+	SetCache(ch)
 
 	program = tea.NewProgram(main)
-	if _, err := program.Run(); err != nil {
-		print("Error running program: %v", err)
-		os.Exit(70)
-	}
+	_, err := program.Run()
+	return err
 }
