@@ -3,7 +3,9 @@ package maps
 type Simple map[string]any
 
 func (m Simple) ToConcurrent() *Concurrent {
-	return &Concurrent{
-		data: m,
+	var cm Concurrent
+	for k, v := range m {
+		cm.Set(k, v)
 	}
+	return &cm
 }
