@@ -4,7 +4,6 @@ import (
 	"net"
 
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
-	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime/http"
 )
 
@@ -22,13 +21,14 @@ type ipAPI struct {
 
 func (i *ipAPI) Get() (*ipData, error) {
 	url := "https://api.ipify.org?format=json"
-	return http.Do[*ipData](&i.Request, url)
+	return http.Do[*ipData](&i.Request, url, nil)
 }
 
 type IPify struct {
-	IP string
+	base
 
 	api IPAPI
+	IP  string
 }
 
 const (
@@ -42,6 +42,8 @@ func (i *IPify) Template() string {
 }
 
 func (i *IPify) Enabled() bool {
+	i.initAPI()
+
 	ip, err := i.getResult()
 	if err != nil {
 		return false
@@ -56,17 +58,22 @@ func (i *IPify) getResult() (string, error) {
 	if dnsErr, OK := err.(*net.DNSError); OK && dnsErr.IsNotFound {
 		return OFFLINE, nil
 	}
+
 	if err != nil {
 		return "", err
 	}
+
 	return data.IP, err
 }
 
-func (i *IPify) Init(props properties.Properties, env runtime.Environment) {
+func (i *IPify) initAPI() {
+	if i.api != nil {
+		return
+	}
+
 	request := &http.Request{
-		Env:          env,
-		CacheTimeout: props.GetInt(properties.CacheTimeout, 30),
-		HTTPTimeout:  props.GetInt(properties.HTTPTimeout, properties.DefaultHTTPTimeout),
+		Env:         i.env,
+		HTTPTimeout: i.props.GetInt(properties.HTTPTimeout, properties.DefaultHTTPTimeout),
 	}
 
 	i.api = &ipAPI{
